.. image:: images/legwork.png
   :width: 400
   :alt: logo for legwork
   :align: center

|

**LEGWORK** (**L**\ ISA **E**\ volution and **G**\ ravitational **W**\ ave **OR**\ bit **K**\ it) is a python package designed to calculate signal to noise ratios for GWs emitted from inspiraling binary systems that are potentially observable by LISA. 

LEGWORK also contains a plotting module so you can show off those detectable GW sources of yours and treats any and all kinds of inspiralling binaries. 
Circular and stationary? No problem!
Eccentric and chirping? We've got you covered!

Want to determine if *your* favorite source is detectable by LISA? Let LEGWORK do the legwork and keep the LISA literature free from spurious factors of 2!

.. raw:: html

    <div class="toms-nav-container" style="margin-bottom:50px;">
        <div class="box" data-href="install.html">Install LEGWORK</div>
        <div class="box" data-href="tutorials.html">Learn from tutorials</div>
        <div class="box" data-href="modules.html">Explore the modules</div>
        <div class="box" data-href="notebooks/Derivations.html">Delve into the derivations</div>
    </div>

We are thankful to Lieke van Son for suggesting the name LEGWORK and Stas Babak, Floor Broekgaarden, and Tom Callister, for helpful discussions about the derivation of the signal to noise ratios.

.. toctree::
    :maxdepth: 1
    :hidden:

    Installation <install>
    Tutorials <tutorials>
    Demos <demos>
    Modules <modules>
    Derivations <notebooks/Derivations.ipynb>
    GitHub <https://github.com/TeamLEGWORK/LEGWORK>
    Submit an issue <https://github.com/TeamLEGWORK/LEGWORK/issues/new>
